@@ -82,6 +82,21 @@ bindings = {}
 
 resources.dofile "scripts/defaults.lua"
 
+if not (options.eightball or
+	options.nineball or
+	options.carom or
+	options.experiment) then
+   options.eightball = true
+end
+
+if options.eightball or
+   options.nineball then
+   options.pool = true
+elseif options.carom or
+   options.experiment then
+   options.billiards = true
+end
+
 -- Load per-user configuration.
 
 print "Reading local user configuration."
@@ -114,6 +129,7 @@ else
    io.close (rcfile)
 end
 
+resources.dofile "scripts/experiment.lua"
 resources.dofile "scripts/collision.lua"
 resources.dofile "scripts/observer.lua"
 resources.dofile "scripts/room.lua"
@@ -122,6 +138,10 @@ resources.dofile "scripts/rack.lua"
 resources.dofile "scripts/game.lua"
 resources.dofile "scripts/display.lua"
 resources.dofile "scripts/httpd.lua"
+
+graph.message.lines[1] = "If you're wondering where the GUI is, it's web-based!"
+graph.message.lines[2] = "Visit http://127.0.0.1:29176 with your favorite browser."
+
 -- resources.dofile "scripts/sounds.lua"
 
 -- billiards.striking.slow = function()
