@@ -123,7 +123,7 @@ end
 
 bodies.cue = bodies.capsule {
    length = 0.6 * billiards.cuelength,
-   radius = 2e-3,
+   radius = billiards.cueradius,
    mass =  {billiards.cuemass,
 	    {0, 0, 0},
 	    {billiards.cueinertia, 0, 0,
