@@ -19,40 +19,13 @@ require "morewidgets"
 widgets.small = widgets.face "Sans-14"
 widgets.regular = widgets.face "Sans-20"
 
-graph.fader = frames.timer {
-   period = 0,
-   timeout = 10,
-
-   tick = function (self, n, delta, elapsed)
-	     graph.message.lines[1].opacity = self.timeout - elapsed
-	     graph.message.lines[2].opacity = self.timeout - elapsed
-		
-	     if elapsed >= self.timeout then
-		graph.message = nil
-		self.parent = nil
-	     end
-	  end
-}
-
 graph.message = widgets.display {
    background = {0.28, 0.24, 0.55},
    size = {1, 1},
    padding = {0.03, 0.03},
    align = {-1, -1},
 
-   lines = widgets.column {
-      widgets.small {
-	 size = {0.9, 0},
-	 align = {-1, 0},
-	 text = "If you're wondering where the GUI is, it's web-based!"
-      },
-
-      widgets.small {
-	 size = {0.9, 0},
-	 align = {-1, 0},
-	 text = "Visit http://127.0.0.1:29176 with your favorite browser."
-      }
-   }
+   lines = widgets.column {}
 }
 
 graph.framerate = options.framerate and widgets.display {
@@ -80,3 +53,64 @@ graph.framerate = options.framerate and widgets.display {
       }
    }
 }
+
+local meta = getmetatable (graph.message.lines)
+local oldindex = meta.__index
+local oldnewindex = meta.__newindex
+
+meta.__index = function (self, key)
+		  local widget
+
+		  key = tonumber(key)
+		  widget = oldindex (self, key)
+
+		  if key then
+		     if widget then
+			return widget.text
+		     else
+			return nil
+		     end
+		  else
+		     return oldindex (self, key)
+		  end
+	       end
+
+meta.__newindex = function (self, key, value)
+		     local widget
+
+		     key = tonumber(key)
+		     widget = oldindex (self, key)
+
+		     if key then
+			if not value then
+			   oldnewindex(self, key, nil)
+			else
+			   if not widget then
+			      widget = widgets.small {
+				 size = {0.9, 0},
+				 align = {-1, 0},
+
+				 fader = frames.timer {
+				    period = 0,
+				    timeout = 5,
+				    
+				    tick = function (self, n, delta, elapsed)
+				       self.parent.opacity = self.timeout -
+						             elapsed
+					      
+				       if elapsed >= self.timeout then
+					  self.parent.parent = nil
+				       end
+				    end
+				 }
+			      }
+
+			      oldnewindex (self, key, widget)
+			   end
+			   
+			   widget.text = tostring(value)
+			end
+		     else
+			oldnewindex(self, key, value)
+		     end
+		  end
