@@ -160,7 +160,7 @@
 			lua_pop (_L, 1);
 		    }
 
-/* 		    dSafeNormalize3 (self->axes[j]); */
+		    dSafeNormalize3 (self->axes[j]);
 		    dJointSetAMotorAxis([self joint], j,
 					dJointGetBody([self joint], 0) ? 1 : 0,
 					self->axes[j][0],
