@@ -28,16 +28,30 @@
 {
     [super init];
     
-    self->body = dBodyCreate (_WORLD);
+    dMassSetZero(&self->mass);
+    
+    self->mass.mass = 1;
+    
+    self->mass.I[0] = 1;
+    self->mass.I[1] = 0;
+    self->mass.I[2] = 0;
+    self->mass.I[3] = 0;
 
-    dBodySetData (self->body, self);
-    dBodyDisable (self->body);
-    dBodySetFiniteRotationMode (self->body, 1);
+    self->mass.I[4] = 0;
+    self->mass.I[5] = 1;
+    self->mass.I[6] = 0;
+    self->mass.I[7] = 0;
 
-    if (self->geom) {
-	dGeomSetData (self->geom, self);
-	dGeomSetBody (self->geom, self->body);
-    }
+    self->mass.I[8] = 0;
+    self->mass.I[9] = 0;
+    self->mass.I[10] = 1;
+    self->mass.I[11] = 0;
+
+    self->body = NULL;
+
+    /* Create and attach the body. */
+    
+    [self release];
     
     return self;
 }
