@@ -26,6 +26,7 @@
 -(Box *) init
 {
     self->geom = dCreateBox (NULL, 1, 1, 1);
+    dGeomSetData (self->geom, self);
     
     self->size[0] = 1;
     self->size[1] = 1;
@@ -78,7 +79,7 @@
     }
 }
 
-#if 0
+#ifdef DRAW_VOLUMES
 -(void) traverse
 {
     dReal *l;
