@@ -31,6 +31,8 @@
     gluQuadricNormals(self->quadric, GLU_NONE);
 
     self->geom = dCreateCapsule (NULL, 1, 1);
+    dGeomSetData (self->geom, self);
+
     self->radius = 1;
     self->length = 1;
     
@@ -83,7 +85,7 @@
     }
 }
 
-#if 0
+#ifdef DRAW_VOLUMES
 -(void) traverse
 {
     glUseProgramObjectARB(0);
