@@ -93,80 +93,86 @@ static FT_Library library;
     FT_UInt j, k;
     int x, y, i, size[2];
 
-    FT_Vector *position;
-    FT_Glyph *glyphs;
+    FT_Vector *position = 0;
+    FT_Glyph *glyphs = 0;
     FT_BBox glyph, layout;
 
     unsigned char *pixels;
 
-    position = malloc (strlen(string) * sizeof (FT_Vector));
-    glyphs = malloc (strlen(string) * sizeof (FT_Glyph));
-    slot = face->glyph;
+    if (string) {
+	position = malloc (strlen(string) * sizeof (FT_Vector));
+	glyphs = malloc (strlen(string) * sizeof (FT_Glyph));
+	slot = face->glyph;
 
-    for(i = 0, j = 0, k = 0, x = 0, y = 0;
-	i < strlen(string);
-	i += 1, j = k, x += slot->advance.x / 64) {
-	k = FT_Get_Char_Index(face, ((unsigned char *)string)[i]);
+	for(i = 0, j = 0, k = 0, x = 0, y = 0;
+	    i < strlen(string);
+	    i += 1, j = k, x += slot->advance.x / 64) {
+	    k = FT_Get_Char_Index(face, ((unsigned char *)string)[i]);
 
-	if (FT_HAS_KERNING(face) && j && k ) {
-	    FT_Vector delta;
+	    if (FT_HAS_KERNING(face) && j && k ) {
+		FT_Vector delta;
 
-	    FT_Get_Kerning(face, j, k, FT_KERNING_DEFAULT, &delta);
-	    x += delta.x / 64;
+		FT_Get_Kerning(face, j, k, FT_KERNING_DEFAULT, &delta);
+		x += delta.x / 64;
+	    }
+
+	    position[i].x = x;
+	    position[i].y = y;
+
+	    error = FT_Load_Glyph(face, k, FT_LOAD_DEFAULT);
+	    error = FT_Get_Glyph(face->glyph, &glyphs[i]);
 	}
 
-	position[i].x = x;
-	position[i].y = y;
+	layout.xMin = 32000;
+	layout.yMin = 32000;
+	layout.xMax = -32000;
+	layout.yMax = -32000;
 
-	error = FT_Load_Glyph(face, k, FT_LOAD_DEFAULT);
-	error = FT_Get_Glyph(face->glyph, &glyphs[i]);
-    }
+	for(i = 0 ; i < strlen(string) ; i += 1) {
+	    FT_Glyph_Get_CBox(glyphs[i], FT_GLYPH_BBOX_PIXELS, &glyph);
 
-    layout.xMin = 32000;
-    layout.yMin = 32000;
-    layout.xMax = -32000;
-    layout.yMax = -32000;
+	    glyph.xMin += position[i].x;
+	    glyph.xMax += position[i].x;
+	    glyph.yMin += position[i].y;
+	    glyph.yMax += position[i].y;
 
-    for(i = 0 ; i < strlen(string) ; i += 1) {
-	FT_Glyph_Get_CBox(glyphs[i], FT_GLYPH_BBOX_PIXELS, &glyph);
+	    layout.xMin = glyph.xMin < layout.xMin ? glyph.xMin : layout.xMin;
+	    layout.yMin = glyph.yMin < layout.yMin ? glyph.yMin : layout.yMin;
+	    layout.xMax = glyph.xMax > layout.xMax ? glyph.xMax : layout.xMax;
+	    layout.yMax = glyph.yMax > layout.yMax ? glyph.yMax : layout.yMax;
+	}
 
-	glyph.xMin += position[i].x;
-	glyph.xMax += position[i].x;
-	glyph.yMin += position[i].y;
-	glyph.yMax += position[i].y;
+	size[0] = layout.xMax - layout.xMin + 2;
+	size[1] = layout.yMax - layout.yMin + 2;
 
-	layout.xMin = glyph.xMin < layout.xMin ? glyph.xMin : layout.xMin;
-	layout.yMin = glyph.yMin < layout.yMin ? glyph.yMin : layout.yMin;
-	layout.xMax = glyph.xMax > layout.xMax ? glyph.xMax : layout.xMax;
-	layout.yMax = glyph.yMax > layout.yMax ? glyph.yMax : layout.yMax;
-    }
+	pixels = calloc (size[0] * size[1], sizeof(unsigned char));
 
-    size[0] = layout.xMax - layout.xMin + 2;
-    size[1] = layout.yMax - layout.yMin + 2;
-
-    pixels = calloc (size[0] * size[1], sizeof(unsigned char));
-
-    for(i = 0 ; i < strlen(string) ; i += 1) {
-	error = FT_Glyph_To_Bitmap(&glyphs[i],
-				   FT_RENDER_MODE_NORMAL,
-				   0, 0);
+	for(i = 0 ; i < strlen(string) ; i += 1) {
+	    error = FT_Glyph_To_Bitmap(&glyphs[i],
+				       FT_RENDER_MODE_NORMAL,
+				       0, 0);
 	
-	if (!error) {
-	    FT_BitmapGlyph bitmap;
-	    bitmap = (FT_BitmapGlyph)glyphs[i];
+	    if (!error) {
+		FT_BitmapGlyph bitmap;
+		bitmap = (FT_BitmapGlyph)glyphs[i];
 
-	    for (k = 0 ; k < bitmap->bitmap.rows ; k += 1) {
-		for (j = 0 ; j < bitmap->bitmap.width ; j += 1) {
-		    pixels[(position[i].y - layout.yMin +
-			    bitmap->top - k) * size[0] +
-			   position[i].x - layout.xMin +
-			   bitmap->left + j + 1] =
-			bitmap->bitmap.buffer[k * bitmap->bitmap.pitch + j];
+		for (k = 0 ; k < bitmap->bitmap.rows ; k += 1) {
+		    for (j = 0 ; j < bitmap->bitmap.width ; j += 1) {
+			pixels[(position[i].y - layout.yMin +
+				bitmap->top - k) * size[0] +
+			       position[i].x - layout.xMin +
+			       bitmap->left + j + 1] =
+			    bitmap->bitmap.buffer[k * bitmap->bitmap.pitch + j];
+		    }
 		}
 	    }
-	}
 	
-	FT_Done_Glyph(glyphs[i]);
+	    FT_Done_Glyph(glyphs[i]);
+	}
+    } else {
+	size[0] = 0;
+	size[1] = 0;
+	pixels = NULL;
     }
 
     /* Load the texture. */
@@ -191,10 +197,12 @@ static FT_Library library;
 
     glPixelStorei(GL_UNPACK_ROW_LENGTH, 0);
     glPixelStorei(GL_UNPACK_ALIGNMENT, 4);
-    
-    free(pixels);
-    free(position);
-    free(glyphs);
+
+    if (string) {
+	free(pixels);
+	free(position);
+	free(glyphs);
+    }
 }
 
 @end
