@@ -41,7 +41,7 @@ static Window window;
 static ALCdevice *device;
 
 static int iterate = 1;
-static int hide, frames, grabkeyboard, grabpointer;
+static int hide, frames, grabkeyboard, grabpointer, autorepeat;
 static int focus, defocus, delete;
 static float canvas[3];
 static char *title;
@@ -55,14 +55,17 @@ static int collision = LUA_REFNIL;
 
 static void callback (void *data, dGeomID a, dGeomID b)
 {
-    dBodyID p, q;
     dContactGeom geoms[16];
     dContact contacts[16];
-    dReal mu, epsilon;
+    dReal mu, epsilon, sigma, tau;
     int i, j, n;
 
+    mu = 0.0;
+    epsilon = 0.0;
+    sigma = 0.0;
+    tau = 1.0;
+    
     if (dGeomIsSpace (a) || dGeomIsSpace (b)) {
-
 	/* Recurse into subspaces as needed. */
 	
 	dSpaceCollide2 (a, b, data, &callback);
@@ -75,13 +78,11 @@ static void callback (void *data, dGeomID a, dGeomID b)
 	    dSpaceCollide ((dSpaceID)b, data, &callback);
 	}
     } else {
-	p = dGeomGetBody (a);
-	q = dGeomGetBody (b);
-
-	if (p || q) {
+	if (dGeomGetBody (a) || dGeomGetBody (b)) {	    
 	    n = dCollide (a, b, 16, geoms, sizeof(dContactGeom));
 
 	    for (i = 0, j = 0 ; i < n ; i += 1) {
+		dBodyID p, q;
 		dVector3 u, v, delta;
 		dReal *r, *n, ndotdelta;
 
@@ -90,24 +91,33 @@ static void callback (void *data, dGeomID a, dGeomID b)
 		
 		r = geoms[i].pos;
 		n = geoms[i].normal;
-		
-		dSetZero (u, 3);
-		dSetZero (v, 3);
+		p = dGeomGetBody (geoms[i].g1);
+		q = dGeomGetBody (geoms[i].g2);
 		
 		if (p) {
 		    dBodyGetPointVel (p, r[0], r[1], r[2], u);
+		} else {
+		    dSetZero (u, 3);
 		}
 		
 		if (q) {
 		    dBodyGetPointVel (q, r[0], r[1], r[2], v);
-		}
+		} else {
+		    dSetZero (v, 3);
+		}	
 
 		dOP (delta, -, u, v);		
 		ndotdelta = dDOT(n, delta);
+		
+/* 		if (dGeomGetClass (b) == dTriMeshClass || */
+/* 		    dGeomGetClass (a) == dTriMeshClass) { */
+/* 		    printf ("%d, %f\n", j, ndotdelta); */
+/* 		    printf ("%f, %f, %f\n", n[0], n[1], n[2]); */
+/* 		} */
 
 		/* Only consider this contact if the
 		   relative velocity points inward. */
-		
+
 		if (ndotdelta <= 0) {
 		    contacts[j].geom = geoms[i];
 
@@ -122,8 +132,6 @@ static void callback (void *data, dGeomID a, dGeomID b)
 	    }
 
 	    if (j > 0) {
-		mu = epsilon = 0;
-		    
 		/* Create a collision event. */
 
 		if (collision != LUA_REFNIL) {
@@ -160,14 +168,27 @@ static void callback (void *data, dGeomID a, dGeomID b)
 			lua_pushvalue (_L, -5);
 
 			lua_call (_L, 2, LUA_MULTRET);
-
-			if (lua_gettop (_L) - h_1 >= 3) {
-			    epsilon = lua_tonumber (_L, -2);
-			    mu = lua_tonumber (_L, -3) < dInfinity ?
-				 lua_tonumber (_L, -3) : dInfinity;
 		    
-			    j = j < lua_tonumber (_L, -1) ?
-				j : lua_tonumber (_L, -1);
+			if (lua_type (_L, h_1 + 1) == LUA_TNUMBER) {
+			    j = j < lua_tonumber (_L, h_1 + 1) ?
+				j : lua_tonumber (_L, h_1 + 1);
+			}
+			
+			if (lua_type (_L, h_1 + 2) == LUA_TNUMBER) {
+			    mu = lua_tonumber (_L, h_1 + 2) < dInfinity ?
+				 lua_tonumber (_L, h_1 + 2) : dInfinity;
+			}
+
+			if (lua_type (_L, h_1 + 3) == LUA_TNUMBER) {
+			    epsilon = lua_tonumber (_L, h_1 + 3);
+			}
+
+			if (lua_type (_L, h_1 + 4) == LUA_TNUMBER) {
+			    sigma = lua_tonumber (_L, h_1 + 4);
+			}
+			
+			if (lua_type (_L, h_1 + 5) == LUA_TNUMBER) {
+			    tau = lua_tonumber (_L, h_1 + 5);
 			}
 
 			lua_settop (_L, h_1);
@@ -175,7 +196,7 @@ static void callback (void *data, dGeomID a, dGeomID b)
 		    
 		    lua_settop (_L, h_0);
 		}
-
+		    
 		/* Create the collision joints. */
 	    
 		for (i = 0 ; i < j ; i += 1) {
@@ -186,34 +207,27 @@ static void callback (void *data, dGeomID a, dGeomID b)
 		    if (mu > 0) {
 			contacts[i].surface.mode |= dContactApprox1;
 			contacts[i].surface.mode |= dContactFDir1;
+			contacts[i].surface.mu = mu;
 		    }
 
 		    if (epsilon > 0) {
 			contacts[i].surface.mode |= dContactBounce;
+			contacts[i].surface.bounce = epsilon;
+			contacts[i].surface.bounce_vel = 0.01;
 		    }
 
-		    contacts[i].surface.mu = mu;
-		    contacts[i].surface.bounce = epsilon;
-		    contacts[i].surface.bounce_vel = 0.01;
+		    if (sigma > 0) {
+			contacts[i].surface.mode |= dContactSoftCFM;
+			contacts[i].surface.soft_cfm = sigma;
+		    }
 
-/* 		    if (dGeomGetClass (b) == dCCylinderClass || */
-/* 			dGeomGetClass (a) == dCCylinderClass) { */
-/* 		    } */
-		    
-/* 		    if (dGeomGetClass (b) == dTriMeshClass || */
-/* 			dGeomGetClass (a) == dTriMeshClass) { */
-/* 			float ks = 20750, kd = 1000; */
-			
-/* 			contacts[i].surface.mode |= */
-/* 			    dContactSoftCFM | */
-/* 			    dContactSoftERP; */
-			    
-/* 			contacts[i].surface.soft_erp = 1e-4 * ks / (1e-4 * ks + kd); */
-/* 			contacts[i].surface.soft_cfm = 1 / (1e-4 * ks + kd); */
-/* 		    } */
+		    if (tau < 1) {
+			contacts[i].surface.mode |= dContactSoftERP;
+			contacts[i].surface.soft_erp = tau;
+		    }
 		    
 		    joint = dJointCreateContact (_WORLD, _GROUP, &contacts[i]);
-		    dJointAttach (joint, p, q);
+		    dJointAttach (joint, dGeomGetBody (a), dGeomGetBody (b));
 		}
 	    }
 	}
@@ -669,6 +683,7 @@ int main(int argc, char **argv)
     XVisualInfo *info;
     Colormap colormap;
     XSetWindowAttributes attributes;
+    XKeyboardState keyboard;
     Atom atom;
 
     ALCcontext *audio;
@@ -917,6 +932,10 @@ int main(int argc, char **argv)
        associated visual. */
 
     display = XOpenDisplay(0);
+
+    XGetKeyboardControl (display, &keyboard);
+    autorepeat = keyboard.global_auto_repeat;
+    
     info = glXChooseVisual(display, DefaultScreen(display), configuration);
 
     if (!info) {
@@ -1036,12 +1055,19 @@ int main(int argc, char **argv)
 			    event.xconfigure.height);
 	    } else if (event.type == FocusIn) {
 		lua_rawgeti (_L, LUA_REGISTRYINDEX, focus);
+
+		XAutoRepeatOff (display);
 	    } else if (event.type == FocusOut) {
 		lua_rawgeti (_L, LUA_REGISTRYINDEX, defocus);
+
+		if (autorepeat) {
+		    XAutoRepeatOn (display);
+		}
 	    } else if (event.type == ClientMessage &&
 		       event.xclient.data.l[0] == atom) {
 		lua_rawgeti (_L, LUA_REGISTRYINDEX, delete);
 	    }
+	
 
 	    if (lua_gettop (_L) > h) {
 		if (lua_isfunction (_L, -1)) {
@@ -1116,15 +1142,20 @@ int main(int argc, char **argv)
 	frames += 1;
     } while (iterate);
 
-    /* Close the Lua state. */
-    
-    lua_close (_L);
-
     /* Destroy the audio context. */
     
     if (audio) {
 	alcDestroyContext (audio);
     }
+
+    if (autorepeat) {
+	XAutoRepeatOn (display);
+    }
+
+    /* Finish cleaning up. */
+    
+    lua_close (_L);
+    XCloseDisplay (display);
     
     puts ("Adieu!");
     return 0;
