@@ -302,7 +302,7 @@ static int collide (lua_State *L)
 	contact.geom.normal[i] = normal[i];
     }
 
-    dNormalize3 (contact.geom.normal);
+    dSafeNormalize3 (contact.geom.normal);
 
     printf ("%f, %f, %f\n",
 	    contact.geom.normal[0],
