@@ -26,12 +26,23 @@
 -(Plane *) init
 {
     self->geom = dCreatePlane (NULL, 0, 0, 1, 0);
+    dGeomSetData (self->geom, self);
     
     [super init];
 
     return self;
 }
 
+-(void) fasten
+{
+    /* We're unplacable so do nothing here. */
+}
+
+-(void) release
+{
+    /* We're unplacable so do nothing here. */
+}
+
 -(void) set
 {
     const char *k;
