@@ -25,6 +25,7 @@
 -(Polyhedron *) init
 {
     self->geom = dCreateTriMesh (NULL, self->data, NULL, NULL, NULL);
+    dGeomSetData (self->geom, self);
     
     [super init];
 
@@ -79,7 +80,7 @@
     return self->data;
 }
 
-#if 0
+#ifdef DRAW_VOLUMES
 -(void) traverse
 {
     int i;
