@@ -27,7 +27,9 @@
 }
 
 -(Texture *) initWithPixels: (unsigned char *) pixels
-                     ofSize: (int[3]) n;
+                     ofSize: (int[3]) n
+           andLevelsBetween: (int) base
+	                and: (int) max;
 -(int) width;
 -(int) height;
 -(int) components;
