@@ -21,8 +21,9 @@
 
 @interface Widget: Node {
     GLfloat color[4];
-    float requested[2];
-    float allocated[2];
+    float requested[2], allocated[2], minimum[2];
+    GLfloat padding[2];
+    int align[2];
 }
 
 -(GLfloat *)color;
